# SPIN
*Sorting Points Into Neighborhoods Python Package*

[![Travis](https://api.travis-ci.org/otaviocv/spin.svg?branch=master)](https://travis-ci.org/otaviocv/spin)

## Introduction

**S**orting **P**oints **I**nto **N**eighborhoods is a clustering algorithm
different from the common options available. The method is taken from 

> D. Tsafrir, I. Tsafrir, L. Ein-Dor, O. Zuk, D.A. Notterman, E. Domany, Sorting
> points into neighborhoods (SPIN): data analysis and visualization by ordering
> distance matrices, Bioinformatics, Volume 21, Issue 10, , Pages 2301–2308,
> https://doi.org/10.1093/bioinformatics/bti329

This python relies on another implementation from
[jonataseduardo](https://github.com/jonataseduardo/SPIN).

## Installation


## Quick start

